@@ -1,13 +1,16 @@
 #' Determine if the MRCA priors' taxa names are present in the FASTA files
 #' @inheritParams default_params_doc
-#' @author Richel J.C. Bilderbeek
+#' @return TRUE if the MRCA priors' taxa names are
+#'   present in the FASTA files. FALSE otherwise.
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
 are_mrca_taxa_names_in_fastas <- function(
   mrca_priors,
   fasta_filenames
 ) {
-  testit::assert(are_mrca_priors(mrca_priors))
+  testit::assert(are_mrca_priors(mrca_priors)) # nolint beautier function
   testit::assert(
-    are_mrca_align_ids_in_fastas(
+    are_mrca_align_ids_in_fastas( # nolint beautier function
       mrca_priors = mrca_priors,
       fasta_filenames = fasta_filenames
     )
