@@ -8,20 +8,24 @@
 #'  #     </distribution>
 #'  # </distribution>
 #' @inheritParams default_params_doc
-#' @author Richel J.C. Bilderbeek
-clock_models_to_xml_prior_distr <- function( # nolint internal function
-  clock_models
+#' @return a character vector of XML strings
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
+clock_models_to_xml_prior_distr <- function( # nolint beautier function
+  clock_models,
+  mrca_priors = NA,
+  tipdates_filename = NA
 ) {
-  clock_models <- get_unlinked_clock_models(clock_models)  # nolint internal function
   text <- NULL
 
   for (i in seq_along(clock_models)) {
     clock_model <- clock_models[[i]]
     text <- c(
       text,
-      clock_model_to_xml_prior_distr( # nolint internal function
-        clock_model,
-        i == 1
+      clock_model_to_xml_prior_distr( # nolint beautier function
+        clock_model = clock_model,
+        mrca_priors = mrca_priors,
+        tipdates_filename = tipdates_filename
       )
     )
   }
