@@ -2,13 +2,14 @@
 #' @param input_fasta_filename one FASTA filename
 #' @param nucleotides_uppercase are the nucleotides written in uppercase?
 #'   Yes if TRUE, no if FALSE
-#' @note this function is not intended for regular use, thus its
-#'   long name length is accepted
-#' @author Richel J.C. Bilderbeek
-create_beast2_input_data_sequences <- function( # nolint internal function
+#' @return lines of XML text
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
+create_beast2_input_data_sequences <- function( # nolint beautier function
   input_fasta_filename,
-  nucleotides_uppercase = FALSE
+  beauti_options = create_beauti_options()
 ) {
+  nucleotides_uppercase <- beauti_options$nucleotides_uppercase
   testit::assert(file.exists(input_fasta_filename))
 
   sequences_table <- fasta_file_to_sequences(
@@ -18,16 +19,16 @@ create_beast2_input_data_sequences <- function( # nolint internal function
   for (i in seq(1, nrow(sequences))) {
     row <- sequences[i, ]
     nextline <- paste0(
-      "                    <sequence id=\"seq_",
+      "<sequence id=\"seq_",
       trimws(row[1]),
       "\" taxon=\"",
       trimws(row[1]),
       "\" totalcount=\"4\" value=\"",
       ifelse(nucleotides_uppercase == TRUE, toupper(row[2]), row[2]),
-      "\"/>"
+      "\"/>" # nolint this is no absolute path
     )
     text <- c(text, nextline)
   }
   text <- sort(text, method = "radix")
-  text
+  indent(text = text, n_spaces = beauti_options$sequence_indent) # nolint beautier function
 }
