@@ -3,15 +3,16 @@
 #' @param id the ID of the clock model
 #' @return the clock models with the desired ID, NULL if such a clock model is
 #'   absent
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
 find_clock_model <- function(
   clock_models,
   id
 ) {
-  if (!are_clock_models(clock_models)) {
+  if (!are_clock_models(clock_models)) { # nolint beautier function
     stop("'clock_models' must be a list of clock models")
   }
-  if (!is_id(id)) {
+  if (!is_id(id)) { # nolint beautier function
     stop("'id' must be an ID")
   }
   for (clock_model in clock_models) {
