@@ -1,14 +1,16 @@
 #' Find the first line that satisfies a regex
 #' @param lines lines of tex
 #' @param regex the regex as text
-#' @author Richel J.C. Bilderbeek
+#' @return index of the line
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
 find_first_regex_line <- function(lines, regex) {
   for (i in seq_along(lines)) {
     match <- stringr::str_extract(
       str = lines[i],
       pattern = regex
     )
-    if (!is.na(match)) return(i)
+    if (!is_one_na(match)) return(i) # nolint beautier function
   }
   NA
 }
