@@ -1,13 +1,15 @@
 #' Creates the gamma site models section in the distribution section
 #' of a BEAST2 XML parameter file
 #' @inheritParams default_params_doc
-#' @author Richel J.C. Bilderbeek
-gamma_site_model_to_xml_prior_distr <- function( # nolint internal function
+#' @return lines of XML text
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
+gamma_site_model_to_xml_prior_distr <- function( # nolint beautier function
   site_model
 ) {
-  testit::assert(is_site_model(site_model))
+  testit::assert(is_site_model(site_model)) # nolint beautier function
   id <- site_model$id
-  testit::assert(is_id(id))
+  testit::assert(is_id(id)) # nolint beautier function
 
   text <- NULL
   gamma_site_model <- site_model$gamma_site_model
@@ -17,8 +19,8 @@ gamma_site_model_to_xml_prior_distr <- function( # nolint internal function
       "x=\"@gammaShape.s:", id, "\">"))
     text <- c(
       text,
-      indent(
-        distr_to_xml(
+      indent( # nolint beautier function
+        distr_to_xml( # nolint beautier function
           gamma_site_model$gamma_shape_prior_distr
         ),
         n_spaces = 4
