@@ -5,11 +5,11 @@
 #'   testit::assert(file.exists(filename))
 #'
 #'   create_beast2_input_file(
-#'     input_filenames = filename,
+#'     input_filename = filename,
 #'     "my_beast.xml"
 #'   )
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @export
 get_fasta_filename <- function() {
-  get_beautier_path("test_output_0.fas") # nolint internal function
+  get_beautier_path("test_output_0.fas") # nolint beautier function
 }
