@@ -2,7 +2,7 @@
 #' @param tree_prior a tree_prior,
 #'   as created by \code{\link{create_tree_prior}}
 #' @return the number of parameters a tree prior has
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'  # birth_rate_distr is uniform, which has zero parameters
 #'  # death_rate_distr is uniform, which has zero parameters
@@ -30,30 +30,31 @@
 #'  testit::assert(
 #'    beautier:::get_tree_prior_n_params(create_yule_tree_prior()) == 0
 #'  )
+#' @noRd
 get_tree_prior_n_params <- function(
   tree_prior
 ) {
-  if (!is_tree_prior(tree_prior)) {
+  if (!is_tree_prior(tree_prior)) { # nolint beautier function
     stop("'tree_prior' must be a tree prior")
   }
-  if (is_bd_tree_prior(tree_prior)) {
+  if (is_bd_tree_prior(tree_prior)) { # nolint beautier function
     return(
-      get_distr_n_params(tree_prior$birth_rate_distr) +
-      get_distr_n_params(tree_prior$death_rate_distr)
+      get_distr_n_params(tree_prior$birth_rate_distr) + # nolint beautier function
+      get_distr_n_params(tree_prior$death_rate_distr) # nolint beautier function
     )
-  } else if (is_cbs_tree_prior(tree_prior)) {
+  } else if (is_cbs_tree_prior(tree_prior)) { # nolint beautier function
     return(0)
-  } else if (is_ccp_tree_prior(tree_prior)) {
-    return(get_distr_n_params(tree_prior$pop_size_distr))
-  } else if (is_cep_tree_prior(tree_prior)) {
+  } else if (is_ccp_tree_prior(tree_prior)) { # nolint beautier function
+    return(get_distr_n_params(tree_prior$pop_size_distr)) # nolint beautier function
+  } else if (is_cep_tree_prior(tree_prior)) { # nolint beautier function
     return(
-      get_distr_n_params(tree_prior$pop_size_distr) +
-      get_distr_n_params(tree_prior$growth_rate_distr)
+      get_distr_n_params(tree_prior$pop_size_distr) + # nolint beautier function
+      get_distr_n_params(tree_prior$growth_rate_distr) # nolint beautier function
     )
   } else {
-    testit::assert(is_yule_tree_prior(tree_prior))
+    testit::assert(is_yule_tree_prior(tree_prior)) # nolint beautier function
     return(
-      get_distr_n_params(tree_prior$birth_rate_distr)
+      get_distr_n_params(tree_prior$birth_rate_distr) # nolint beautier function
     )
   }
 }
