@@ -4,14 +4,15 @@
 #' @param id the parameter's ID. Will be ignored if the parameter already
 #'   has an ID
 #' @return an initialized parameter
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
 init_param <- function(
   param,
   id
 ) {
-  testit::assert(is_param(param))
+  testit::assert(is_param(param)) # nolint beautier function
 
-  if (is.na(param$id)) {
+  if (is_one_na(param$id)) { # nolint beautier function
     param$id <- id
   }
 
