@@ -1,11 +1,14 @@
 #' Puts spaces in between the lines
 #' @param lines lines of text
+#' @return interspaced lines of text
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
 interspace <- function(lines) {
 
   if (length(lines) == 0) return(lines)
 
   # number of spaces of non-indented line
-  nsni <- count_trailing_spaces(lines[1]) # nolint internal function
+  nsni <- count_trailing_spaces(lines[1]) # nolint beautier function
 
   result <- NULL
   for (i in seq_along(lines)) {
