@@ -3,12 +3,13 @@
 #' @param x the object to check if it is an
 #'   initialized parameter
 #' @return TRUE if x is an initialized parameter, FALSE otherwise
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
 is_init_param <- function(
   x
 ) {
-  if (!is_param(x)) {
+  if (!is_param(x)) { # nolint beautier function
     stop("'x' must be a parameter")
   }
-  !is.na(x$id)
+  !is_one_na(x$id) # nolint beautier function
 }
