@@ -1,7 +1,7 @@
 #' Determines if the name is a valid parameter name
 #' @param name the name to be tested
 #' @return TRUE if the name is a valid parameter name, FALSE otherwise
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   testit::assert(beautier:::is_param_name("alpha"))
 #'   testit::assert(beautier:::is_param_name("beta"))
@@ -21,6 +21,7 @@
 #'   testit::assert(beautier:::is_param_name("s"))
 #'   testit::assert(beautier:::is_param_name("scale"))
 #'   testit::assert(beautier:::is_param_name("sigma"))
+#' @noRd
 is_param_name <- function(name) {
-  name %in% get_param_names() # nolint internal function
+  name %in% get_param_names() # nolint beautier function
 }
