@@ -6,7 +6,8 @@
 #'   testit::assert(beautier:::is_site_model_name("HKY"))
 #'   testit::assert(beautier:::is_site_model_name("TN93"))
 #'   testit::assert(beautier:::is_site_model_name("GTR"))
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
 is_site_model_name <- function(name) {
-  name %in% get_site_model_names() # nolint internal function
+  name %in% get_site_model_names() # nolint beautier function
 }
