@@ -17,7 +17,8 @@
 #'   testit::assert(
 #'     beautier:::is_tree_prior_name("yule")
 #'   )
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
 is_tree_prior_name <- function(name) {
-  name %in% get_tree_prior_names() # nolint internal function
+  name %in% get_tree_prior_names() # nolint beautier function
 }
