@@ -1,7 +1,9 @@
-#' Creates the distribution section in the prior section of the
-#' distribution section of a BEAST2 XML parameter file.
-#' These lines start with '<distribution id='
+#' Creates the the \code{distribution}'s prior section (which is part of
+#' a posterior distribution section) of a BEAST2 XML parameter file.
+#'
+#' These lines start with '\code{<distribution id="prior"}'
 #' @inheritParams default_params_doc
+#' @return lines of XML text
 #' @examples
 #'  # <distribution id="posterior" spec="util.CompoundDistribution">
 #'  #     <distribution id="prior" spec="util.CompoundDistribution">
@@ -10,31 +12,30 @@
 #'  #     <distribution id="likelihood" ...>
 #'  #     </distribution>
 #'  # </distribution>
-#' @author Richel J.C. Bilderbeek
-mrca_priors_to_xml_prior_distr <- function( # nolint internal function
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
+mrca_priors_to_xml_prior_distr <- function( # nolint beautier function
   mrca_priors,
   has_non_strict_clock_model
 ) {
-  testit::assert(are_mrca_priors(mrca_priors))
-  if (length(mrca_priors) == 1 && is.na(mrca_priors)) return(NULL)
+  testit::assert(are_mrca_priors(mrca_priors)) # nolint beautier function
+  if (length(mrca_priors) == 1 && is_one_na(mrca_priors)) return(NULL) # nolint beautier function
 
   text <- NULL
   taxa_names_with_ids <- NULL
-  is_first <- TRUE
   for (mrca_prior in mrca_priors) {
     text <- c(
       text,
       mrca_prior_to_xml_prior_distr(
         mrca_prior,
         has_non_strict_clock_model = has_non_strict_clock_model,
-        taxa_names_with_ids = taxa_names_with_ids,
-        is_first = is_first
+        taxa_names_with_ids = taxa_names_with_ids
       )
     )
+    testit::assert(!is_one_na(mrca_prior$taxa_names)) # nolint beautier function
     taxa_names_with_ids <- unique(
       c(taxa_names_with_ids, mrca_prior$taxa_names)
     )
-    is_first <- FALSE
   }
   text
 }
