@@ -1,29 +1,30 @@
-#' Creates the mrca priors' XML for the tracelog section
+#' Creates the MRCA priors' XML for the tracelog section
 #' @inheritParams default_params_doc
+#' @return lines of XML text
 #' @seealso the complete tracelog section is created
 #'   by \code{\link{create_beast2_input_tracelog}}
 #' @examples
 #' # <logger id="tracelog" ...>
 #' #'   # Here
 #' # </logger>
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
 mrca_priors_to_xml_tracelog <- function(
+  clock_models,
   mrca_priors,
-  has_non_strict_clock_model = FALSE
+  tipdates_filename = NA
 ) {
-  testit::assert(are_mrca_priors(mrca_priors))
+  testit::assert(are_mrca_priors(mrca_priors)) # nolint beautier function
   text <- NULL
-  is_first <- TRUE
 
   for (mrca_prior in mrca_priors) {
     text <- c(text,
       mrca_prior_to_xml_tracelog(
+        clock_models = clock_models,
         mrca_prior = mrca_prior,
-        has_non_strict_clock_model = has_non_strict_clock_model,
-        is_first = is_first
+        tipdates_filename = tipdates_filename
       )
     )
-    is_first <- FALSE
   }
   text
 }
