@@ -2,11 +2,12 @@
 #'   as used in the \code{init} section
 #' @inheritParams default_params_doc
 #' @return the phylogeny as XML text
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
 rnd_phylo_to_xml_init <- function(
   id
 ) {
-  testit::assert(is_id(id))
+  testit::assert(is_id(id)) # nolint beautier function
   text <- NULL
   text <- c(text, paste0("<init id=\"RandomTree.t:", id,
     "\" spec=\"beast.evolution.tree.RandomTree\" estimate=\"false\"",
