@@ -3,20 +3,17 @@
 #' @inheritParams default_params_doc
 #' @return lines of XML text, without indentation nor \code{state}
 #'   tags
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
 site_models_to_xml_state <- function(
   site_models
 ) {
-  testit::assert(are_site_models(site_models))
-
-  # Remove the clock models that share a same alignment
-  site_models <- get_unlinked_site_models(site_models) # nolint internal function
-  testit::assert(are_site_models(site_models))
+  testit::assert(are_site_models(site_models)) # nolint beautier function
 
   text <- NULL
   for (site_model in site_models) {
     text <- c(text,
-      site_model_to_xml_state(site_model)
+      site_model_to_xml_state(site_model) # nolint beautier function
     )
   }
   text
