@@ -2,13 +2,14 @@
 #'   as used in the \code{operators} section
 #' @inheritParams default_params_doc
 #' @return the tree priors as XML text
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
+#' @noRd
 tree_priors_to_xml_operators <- function(
   tree_priors,
   fixed_crown_ages = rep(FALSE, times = length(tree_priors))
 ) {
 
-  testit::assert(are_tree_priors(tree_priors))
+  testit::assert(are_tree_priors(tree_priors)) # nolint beautier function
   testit::assert(is.logical(fixed_crown_ages))
   testit::assert(length(tree_priors) == length(fixed_crown_ages))
 
